@@ -158,7 +158,7 @@ class GNN(PyTorchModel):
         elif self._readout_method == READOUT_SUM:
             return global_add_pool(node_embs, batch_idx)
         else:
-            raise AssertionError('Unknown readout method {}.'.format(self._readout_METHOD))
+            raise AssertionError('Unknown readout method {}.'.format(self._readout_method))
 
     def forward(self,
                 x: Union[Batch, torch_geometric.data.Data]) -> torch.Tensor:
